Open Science
============

The open source ASReview LAB software is one of the products of `Utrecht
University's AI Lab "AI-aided Knowledge Discovery"
<https://www.uu.nl/en/research/ai-labs/disc-ai-lab>`_. The lab focuses on
developing efficient, open, and trustworthy human-AI interaction for processing
large amounts of text data. Emphasizing open-source and community-driven
efforts, our collaborative research aims to reduce the time and resources needed
to process text data while increasing transparency, reproducibility, and
explainability.

.. note::

  The ASReview project is developed by researchers for researchers, and anyone
  is welcome to join the community!

There is still lots of research that can be published using the ASReview
products. We welcome researchers worldwide to discover and conduct new research,
such as applying the existing models to new types of datasets (different
scientific fields, other languages, multilingual data, text data outside
academia, large datasets, etc.), adding new models and testing their performance
on the available benchmark datasets, introducing and evaluating new stopping
rules or performance metrics, and more!

Scientific principles
---------------------

The research team works according to the Open Science principles and invests in
an inclusive community contributing to the project. In short, research is
conducted according to the following fundamental principles:

- Research output should be `FAIR <https://www.uu.nl/en/research/open-science>`_
  (Findable Accessible Interoperable and Reusable).
- Research should be conducted with integrity, and we commit ourselves to the
  `Netherlands Code of Conduct for Research Integrity
  <https://www.nwo.nl/en/netherlands-code-conduct-research-integrity>`_.
- Output should be rewarded according to the Declaration on Research Assessment
  (`DORA <https://sfdora.org/read/>`_).


Utrecht University has established `specific regulations
<https://www.uu.nl/en/organisation/about-us/codes-of-conduct>`_ governing
conduct for its employees. These are based on the key principles of professional
and quality academic conduct and ethically-responsible research. Members of the
team employed by Utrecht University, commit themselves to these regulations in
all their conduct, including all work related to ASReview. Adherence to similar
key principles is expected of all researchers involved in all facets of the
ASReview project.

Cite
----

For scientific use, we encourage users to cite:

  van de Schoot, R., de Bruin, J., Schram, R. et al. An open source machine
  learning framework for efficient and transparent systematic reviews. Nat Mach
  Intell 3, 125–133 (2021). https://doi.org/10.1038/s42256-020-00287-7

For citing the software itself, we recommend to use the Cite button on the
project overview page of ASReview LAB. This will included the version of the
software you used.

For a detailed description of the the data model and it's reproducibility
features, we refer to the

  Lombaers, P., de Bruin, J., & van de Schoot, R. (2024). Reproducibility and
  Data Storage for Active Learning-Aided Systematic Reviews. Applied Sciences,
  14(9), 3842. https://doi.org/10.3390/app14093842

More studies related to the project can be found on `asreview.ai/research
<https://asreview.ai/research/>`_.


Collaborate
-----------

Are you interested in (scientific) collaboration? You can `contact Prof. Dr.
Rens van de Schoot <https://www.rensvandeschoot.com/contact/>`_ or send an email
to asreview@uu.nl.


Contribute
----------

We warmly welcome contributions from everyone, whether you're a seasoned
developer, a researcher, or just someone passionate about open science! There
are many ways to get involved, and it might be easier than you think.

- **Ask Questions**: If you're curious about ASReview or have questions, feel
  free to ask on `GitHub Discussions
  <https://github.com/asreview/asreview/discussions>`__. Your questions might
  help others too!

- **Report Issues**: Found a bug or have a feature request? Submit an issue on
  `GitHub <https://github.com/asreview/asreview/issues/new/choose>`__. Clear and
  detailed reports are incredibly valuable.

- **Share Your Experiences**: Write a blog post, tweet about your experience, or
  share your use case on the `Discussion platform
  <https://github.com/asreview/asreview/discussions>`_. Your story could inspire
  others to use ASReview in innovative ways.

- **Contribute Code**: If you're a developer, check out our `CONTRIBUTING.md
  <https://github.com/asreview/asreview/blob/main/CONTRIBUTING.md>`_ for
  instructions on how to get started. We also have detailed guidelines for
  `developers
  <https://github.com/asreview/asreview/blob/main/DEVELOPMENT.md>`_.

- **Improve Documentation**: Help us make our documentation better! If you spot
  errors or think something could be explained more clearly, feel free to
  suggest changes.

- **Test New Features**: Try out new features and provide feedback. Your input
  helps us improve the software.

- **Spread the Word**: Share ASReview with your colleagues, friends, or on
  social media. The more people know about it, the bigger our community grows!

In a `blog post <https://asreview.nl/blog/open-source-and-research/>`_, we list
some simple examples for first-time contributors. Even small contributions, like
answering user questions, are greatly appreciated.

.. note::

	All contributions, whether small or large, are greatly appreciated! Together,
	we can make ASReview even better.


Donate
------

ASReview is Free and Open Source Software (FOSS). To support its development,
you can make a donation on the `ASReview donation page
<https://asreview.ai/donate/>`_. Even small contributions are highly
appreciated!
